@@ -1,7 +1,5 @@
-try:
-    from urllib.request import urlopen
-except ImportError:
-    from urllib2 import urlopen
+from urllib.request import urlopen
+
 import yaml
 
 
