@@ -31,8 +31,6 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from __future__ import print_function
-
 import gzip
 import os
 import re
@@ -155,12 +153,7 @@ class CacheYamlDumper(yaml.SafeDumper):
 
     def ignore_aliases(self, content):
         """ Allow strings that look like package XML to alias to each other in the YAML output. """
-        try:
-            basestring
-        except NameError:
-            # Python 3
-            basestring = str
-        return not (isinstance(content, basestring) and '<package' in content)
+        return not (isinstance(content, str) and '<package' in content)
 
     def represent_mapping(self, tag, mapping, flow_style=False):
         """ Gives compact representation for the distribution_file section, while allowing the package
