@@ -6,11 +6,13 @@ from rosdistro.loader import load_url
 
 import yaml
 
+from . import path_to_url
+
 FILES_DIR = os.path.normpath(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'files'))
 
 
 def test_distribution_file():
-    url = 'file://' + FILES_DIR + '/foo/distribution.yaml'
+    url = path_to_url(os.path.join(FILES_DIR, 'foo', 'distribution.yaml'))
     yaml_str = load_url(url)
     data = yaml.safe_load(yaml_str)
     dist_file = DistributionFile('foo', data)
@@ -18,7 +20,7 @@ def test_distribution_file():
 
 
 def test_get_distribution_file():
-    url = 'file://' + FILES_DIR + '/index_v2.yaml'
+    url = path_to_url(os.path.join(FILES_DIR, 'index_v2.yaml'))
     i = get_index(url)
     dist_file = get_distribution_file(i, 'foo')
     _validate_dist_file(dist_file)
